summaryrefslogtreecommitdiff
path: root/lisp/dframe.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/dframe.el')
-rw-r--r--lisp/dframe.el7
1 files changed, 3 insertions, 4 deletions
diff --git a/lisp/dframe.el b/lisp/dframe.el
index 2cdf4784eb0..59849e98c9e 100644
--- a/lisp/dframe.el
+++ b/lisp/dframe.el
@@ -516,7 +516,7 @@ LOCATION can be one of 'random, 'left-right, or 'top-bottom."
(defun dframe-needed-height (&optional frame)
"The needed height for the tool bar FRAME (in characters)."
(or frame (setq frame (selected-frame)))
;; The 1 is the missing modeline/minibuffer
(+ 1 (/ (frame-pixel-height frame)
;; This obscure code avoids a byte compiler warning in Emacs.
(let ((f 'face-height))
@@ -969,7 +969,7 @@ broken because of the dedicated frame."
(switch-to-buffer buffer)
(call-interactively 'switch-to-buffer nil nil)))
;; XEmacs: this can be implemented using modeline keymaps, but there
;; is no use, as we have horizontal scrollbar (as the docstring
;; hints.)
(defun dframe-mouse-hscroll (e)
@@ -987,8 +987,7 @@ mode-line. This is only useful for non-XEmacs."
((> click-col (- (window-width) 5))
(scroll-right 2))
(t (dframe-message
- "Click on the edge of the modeline to scroll left/right")))
- ))
+ "Click on the edge of the mode line to scroll left/right")))))
(provide 'dframe)
@@ -516,7 +516,7 @@ LOCATION can be one of 'random, 'left-right, or 'top-bottom."
"The needed height for the tool bar FRAME (in characters)."
(or frame (setq frame (selected-frame)))
- ;; The 1 is the missing modeline/minibuffer
+ ;; The 1 is the missing mode line or minibuffer
(+ 1 (/ (frame-pixel-height frame)
;; This obscure code avoids a byte compiler warning in Emacs.
@@ -969,7 +969,7 @@ broken because of the dedicated frame."
(switch-to-buffer buffer)
(call-interactively 'switch-to-buffer nil nil)))
-;; XEmacs: this can be implemented using modeline keymaps, but there
+;; XEmacs: this can be implemented using mode line keymaps, but there
;; is no use, as we have horizontal scrollbar (as the docstring
;; hints.)